package org.apache.commons.lang3.function;

import java.lang.Throwable;
import java.util.Objects;

@FunctionalInterface
/* loaded from: org_apache_commons_lang3_function.jar:org/apache/commons/lang3/function/FailablePredicate.class */
public interface FailablePredicate<T, E extends Throwable> {
    public static final FailablePredicate FALSE = t -> {
        return false;
    };
    public static final FailablePredicate TRUE = t -> {
        return true;
    };

    boolean test(T t) throws Throwable;

    static <T, E extends Throwable> FailablePredicate<T, E> falsePredicate() {
        return FALSE;
    }

    static <T, E extends Throwable> FailablePredicate<T, E> truePredicate() {
        return TRUE;
    }

    default FailablePredicate<T, E> and(FailablePredicate<? super T, E> other) {
        Objects.requireNonNull(other);
        return obj -> {
            return test(obj) && other.test(obj);
        };
    }

    default FailablePredicate<T, E> negate() {
        return obj -> {
            return !test(obj);
        };
    }

    default FailablePredicate<T, E> or(FailablePredicate<? super T, E> other) {
        Objects.requireNonNull(other);
        return obj -> {
            return test(obj) || other.test(obj);
        };
    }
}
